@@ -1,4 +1,4 @@
-/*
+	/*
 qgvdial is a cross platform Google Voice Dialer
 Copyright (C) 2009-2014  Yuvraaj Kelkar
 
@@ -200,7 +200,7 @@ IMainWindow::loginCompleted()
     mEvent.distinct_id = m_user;
     mEvent.distinct_id = mEvent.distinct_id.toLower ();
     mEvent.properties["os"] = Lib::ref().getOsDetails();
-    mEvent.properties["version"] = "0.4.1851";
+    mEvent.properties["version"] = "0.4.1864";
 
     do {
         if (ATTS_SUCCESS == task->status) {
@@ -306,12 +306,17 @@ IMainWindow::onUserLogoutRequest()
 void
 IMainWindow::onLogoutDone()
 {
-    m_mixPanel.addEvent(m_user, "Logout");
-
     AsyncTaskToken *task = (AsyncTaskToken *)QObject::sender();
+
+    if (task->status != ATTS_SUCCESS) {
+        m_mixPanel.addEvent(m_user, "Logout failed");
+    } else {
+        m_mixPanel.addEvent(m_user, "Logout");
+    }
+
     uiSetUserPass (true);
     onUserLogoutDone();
-    task->deleteLater ();
+    task->deleteLater();
 }//IMainWindow::onLogoutDone
 
 void
